==> wxpython4.0_4.2.2+dfsg.orig.tar.xz: wxPython-4.2.2/etg/dirdlg.py <==
#---------------------------------------------------------------------------
# Name:        etg/dirdlg.py
# Author:      Kevin Ollivier
#
# Created:     10-Sept-2011
# Copyright:   (c) 2011 by Kevin Ollivier
# Copyright:   (c) 2011-2020 by Total Control Software
# License:     wxWindows License
#---------------------------------------------------------------------------

import etgtools
import etgtools.tweaker_tools as tools

PACKAGE   = "wx"
MODULE    = "_core"
NAME      = "dirdlg"   # Base name of the file to generate to for this script
DOCSTRING = ""

# The classes and/or the basename of the Doxygen XML files to be processed by
# this script.
ITEMS  = [ 'wxDirDialog' ]

#---------------------------------------------------------------------------

def run():
    # Parse the XML file(s) building a collection of Extractor objects
    module = etgtools.ModuleDef(PACKAGE, MODULE, NAME, DOCSTRING)
    etgtools.parseDoxyXML(module, ITEMS)

    #-----------------------------------------------------------------
    # Tweak the parsed meta objects in the module object as needed for
    # customizing the generated code and docstrings.

    c = module.find('wxDirDialog')
    module.addGlobalStr('wxDirDialogNameStr', c)
    module.addGlobalStr('wxDirDialogDefaultFolderStr', c)

    tools.fixWindowClass(c)

    module.find('wxDirSelectorPromptStr').ignore()

    c = module.find('wxDirSelector')
    c.mustHaveApp()

    #-----------------------------------------------------------------
    tools.doCommonTweaks(module)
    tools.runGenerators(module)


#---------------------------------------------------------------------------
if __name__ == '__main__':
    run()

==> wxpython4.0_4.2.3+dfsg.orig.tar.xz: wxPython-4.2.3/etg/dirdlg.py <==
#---------------------------------------------------------------------------
# Name:        etg/dirdlg.py
# Author:      Kevin Ollivier
#
# Created:     10-Sept-2011
# Copyright:   (c) 2011 by Kevin Ollivier
# Copyright:   (c) 2011-2020 by Total Control Software
# License:     wxWindows License
#---------------------------------------------------------------------------

import etgtools
import etgtools.tweaker_tools as tools

PACKAGE   = "wx"
MODULE    = "_core"
NAME      = "dirdlg"   # Base name of the file to generate to for this script
DOCSTRING = ""

# The classes and/or the basename of the Doxygen XML files to be processed by
# this script.
ITEMS  = [ 'wxDirDialog' ]

#---------------------------------------------------------------------------

def run():
    # Parse the XML file(s) building a collection of Extractor objects
    module = etgtools.ModuleDef(PACKAGE, MODULE, NAME, DOCSTRING)
    etgtools.parseDoxyXML(module, ITEMS)

    #-----------------------------------------------------------------
    # Tweak the parsed meta objects in the module object as needed for
    # customizing the generated code and docstrings.

    c = module.find('wxDirDialog')
    module.addGlobalStr('wxDirDialogNameStr', c)
    module.addGlobalStr('wxDirDialogDefaultFolderStr', c)

    tools.fixWindowClass(c)

    module.find('wxDirSelectorPromptStr').ignore()

    c.find('GetPaths').ignore()
    c.addCppMethod('wxArrayString*', 'GetPaths', '()', pyArgsString="() -> list",
        doc='Returns a list of the currently selected paths.',
        body="""\
            wxArrayString* paths = new wxArrayString;
            self->GetPaths(*paths);
            return paths;
            """
    )

    c = module.find('wxDirSelector')
    c.mustHaveApp()

    #-----------------------------------------------------------------
    tools.doCommonTweaks(module)
    tools.runGenerators(module)


#---------------------------------------------------------------------------
if __name__ == '__main__':
    run()
